-- Automatically generated
return { manifest = {
	components =
	{
		{
			name = "@sys.appcon.AVTC",
			location = "bin",
			depends    = {},
			provides   = {},
			parameters = { purge=false, autostart=true },
			version = "1.0.0.001",
		}
	}
}, build = "2019-05-14T20:45:02-07:00", commit = "39edb63" }
